library(tidyverse)
library(infer)

library(ggplot2movies)  # Over 58,000 movie records (rows)


movies_slim <- movies %>%
  select(title,year,length,budget,votes,rating,Action,Comedy,Drama,Romance)

# Random selection of 10 rows
movies_slim %>%
  slice_sample(n=10)

# Filter for modern movies, full length, with enough votes that the ratings are relaible
summary(movies_slim$votes)
summary(movies_slim$length)

movies_filtered <-  movies_slim %>%
  filter(votes>=500 & year>=1970 & length>=70) %>%
  drop_na(rating)   # Obviously we don't want NA ratings

# Infer package needs explanatory variable with exactly two categories
# Also, don't want movies that are both comedy and action
movies_final <-  movies_filtered %>%
  filter( (Action == 1 | Comedy == 1) & !(Action == 1 & Comedy == 1) ) %>%
  mutate(genre = case_when(
    (Action == 1) ~ 'Action',
    (Comedy == 1) ~ 'Comedy'
  ))

nrow(movies_final)
unique(movies_final$genre)

# Plot of Action ratings
movies_final %>%
  filter(genre == "Action") %>%
  ggplot(mapping = aes(x = rating)) +
  geom_histogram(color = "white")

# Plot of Comedy ratings
movies_final %>%
  filter(genre == "Comedy") %>%
  ggplot(mapping = aes(x = rating)) +
  geom_histogram(color = "white")


# Boxplots by Genre
ggplot(data = movies_final, aes(x = genre, y = rating)) +
  geom_boxplot()

# Descriptive Stats by Genre
movies_final %>%
  group_by(genre) %>%
  summarize(n = n(), mean_rating = mean(rating), std_dev = sd(rating))

# Diff of Means Test
# Null Hypothesis:         μ_1 - μ_2 = 0
# Alternative Hypothesis:  μ_1 - μ_2 ≠ 0
########################################################################################


# Calculate the Simulation-Based Null Distribution
null_dist_movies <-  movies_final %>%
  specify(response = rating, explanatory = genre) %>%
  hypothesize(null = "independence") %>%
  generate(reps = 10000, type = "permute") %>%
  calculate(stat = "diff in means", order = c("Comedy", "Action"))

# Calculate p-value
null_dist_movies %>%
  get_p_value(obs_stat = 0.11634, direction = "both")

# Helpful visualization of Null Distribution and p-value
visualize(null_dist_movies) +
  shade_p_value(obs_stat = 0.11634, direction = "two_sided")
